@@ -34,7 +34,7 @@ use parent 'LyricFinder::_Class';
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-our $VERSION = '1.31';
+our $VERSION = '1.32';
 our $DEBUG = 0;  # If you want debug messages, set debug to a true value
 
 my @supported_mods = (qw(Cache ApiLyricsOvh AZLyrics ChartLyrics Genius Letras Musixmatch));
@@ -296,8 +296,8 @@ L<LyricFinder::Musixmatch> (www.musixmatch.com).  There is a
 special module for storing and / or fetching lyrics (.lrc) files already 
 stored locally, called L<LyricFinder::Cache>.
 
-This module is derived from the (older) Lyrics::Fetcher collection of modules 
-by (c) 2007-2020 David Precious, but currently (as of December, 2020) supports 
+This module is derived from the (older) L<Lyrics::Fetcher> collection of modules 
+by (c) 2007-2020 David Precious, but currently supports 
 more lyric sites (6) and bundles all the supported site modules together here 
 (simply install this one module).  We have reworked the "Cache" module to 
 cache lyrics files by artist and song title on disk in the user's desired 
@@ -305,9 +305,9 @@ location.  LyricFinder is also truly object-oriented making interaction with
 the user-facing methods and data easier and more streamlined.
 
 NOTE:  This module is used completely independent of any of those modules, 
-but the code is derived from them, as allowed by and the license and credits 
-are included here, as required by their open-source license.  It is capable 
-of being used as a drop-in replacement, but some function names and 
+but some of the code is derived from them, as allowed by and the license and 
+credits are included here, as required by their open-source license.  It is 
+capable of being used as a drop-in replacement, but some function names and 
 other code changes will be needed.
 
 We've also added methods to easily change the "user-agent" passed to the 
@@ -321,8 +321,10 @@ Media Player" that frequently stream internet radio stations, which can
 impose a "hit" on the lyrics sites each time the song title changes.  This 
 reduces the odds of a user's IP-address possibly being banned by a lyrics site 
 for "too-frequent scraping / usage"!  NOTE:  If you want to prevent the usage 
-of one or more of the specific sites, simply delete or rename that site's 
-submodule file.  If you want to use one or more specific sites, or enforce 
+of one or more of the specific sites, simply specify the I<-omit> argument with 
+a reference to a list of module names to skip, 
+ie. I<-omit => 'AZLyrics,Genius'> in the I<new LyricFinder()> function.  
+If you want to use one or more specific sites, or enforce 
 a specific search order, you can call the fetch() method with a third 
 argument consisting of the site module name, ie. "Musixmatch", or reference to 
 an array of site module names, ie. [Genius, AZLyrics].  If you specify "Cache" 
@@ -481,7 +483,7 @@ Some sites are pickey about receiving a user-agent
 string that corresponds to a valid / supported web-browser to prevent their 
 sites from being "scraped" by programs, such as this.  
 
-Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:80.0) Gecko/20100101 Firefox/80.0">
+Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:112.0) Gecko/20100101 Firefox/112.0">
 
 If no argument is passed, it returns the current GENERAL user-agent string in 
 effect (but a different agent option is specified for a specific module may 
@@ -594,7 +596,7 @@ the last successful fetch (or "none" if the fetch failed).
 
 =item [ I<$arrayref> | I<@array> ] = $finder->B<sources>()
 
-Returns a list of available site modules.  Similar to Lyric::Fetcher's 
+Returns a list of available site modules.  Similar to Lyrics::Fetcher's 
 I<available_fetchers>() function.
 
 =item [ I<$scalar> | I<@array> ] = $finder->B<tried>()
